Crate nfc [−] [src]
Modules
| device | |
| error | |
| ffi | |
| initiator | |
| misc | |
| target | |
| to_str |
Functions
| abort_command |
Aborts current running command |
| close |
Close from a NFC device |
| exit |
Deinitializes libnfc. Should be called after closing all open devices and before your application terminates |
| idle |
Switches the NFC device to idle mode |
| init |
Initializes libnfc. This function must be called before calling any other libnfc function |
| list_devices |
Scan for discoverable supported devices |
| open |
Open an NFC device |
| register_driver |
Registers an NFC device driver with libnfc |